@@ -1,8 +1,8 @@
-## ----end_point_info, eval=FALSE------------------------------------------
+## ----end_point_info, eval=FALSE-----------------------------------------------
 #  library(toxEval)
 #  end_point_info <- end_point_info
 
-## ----eval=FALSE----------------------------------------------------------
+## ----eval=FALSE---------------------------------------------------------------
 #  filtered_ep <- filter_groups(end_point_info,
 #                groupCol = "intended_target_family",
 #                assays = c("ATG","NVS", "OT", "TOX21",
@@ -11,12 +11,15 @@
 #                remove_groups = c("Background Measurement",
 #                                  "Undefined"))
 
-## ---- eval=FALSE---------------------------------------------------------
+## ---- eval=FALSE--------------------------------------------------------------
 #  install.packages("toxEval")
 
-## ----eval=FALSE----------------------------------------------------------
+## ----update, echo=FALSE-------------------------------------------------------
+knitr::include_graphics("update.png")
+
+## ----eval=FALSE---------------------------------------------------------------
 #  update.packages()
 
-## ---- eval=TRUE----------------------------------------------------------
+## ---- eval=TRUE---------------------------------------------------------------
 citation(package = "toxEval")
 
