@@ -149,14 +149,14 @@ test_that("Table functions", {
                     "DNA Binding freq","Nuclear Receptor maxEAR",
                     "Nuclear Receptor freq","Esterase maxEAR",
                     "Cell Cycle freq", "Cell Cycle maxEAR") %in% names(statStuff)))
-  expect_equal(round(statStuff[["DNA Binding maxEAR"]][which(statStuff[["site"]] == "Raisin")],4),4.2992)
-  expect_equal(round(statStuff[["DNA Binding freq"]][which(statStuff[["site"]] == "Raisin")],4),0.8409)
+  expect_equal(round(statStuff[["DNA Binding maxEAR"]][which(statStuff[["site"]] == "Raisin")],4),0.0271)
+  expect_equal(round(statStuff[["DNA Binding freq"]][which(statStuff[["site"]] == "Raisin")],4),0)
   
   groupStuff <- hits_summary(chemical_summary, "Biological", hit_threshold = 1)
   expect_true(all(unique(groupStuff$site) %in% chem_site$`Short Name`))
   expect_true(all(c("site","category","Samples with hits","Number of Samples") %in% names(groupStuff)))
   expect_equal(groupStuff[["Samples with hits"]][which(groupStuff[["site"]] == "Raisin" &
-                                                           groupStuff[["category"]] == "DNA Binding")],28)
+                                                           groupStuff[["category"]] == "Nuclear Receptor")],17)
   expect_equal(groupStuff[["Number of Samples"]][which(groupStuff[["site"]] == "Raisin" &
                                                        groupStuff[["category"]] == "DNA Binding")],44)
   
@@ -168,11 +168,11 @@ test_that("Chem plotting functions", {
   graphData <- graph_chem_data(chemical_summary)
   expect_true(all(names(graphData) %in% c("site","chnm","Class","meanEAR")))
   expect_equal(levels(graphData$Class)[1], "Detergent Metabolites")
-  expect_equal(levels(graphData$Class)[length(levels(graphData$Class))], "Fuels")
+  expect_equal(levels(graphData$Class)[length(levels(graphData$Class))], "Dyes/Pigments")
   expect_equal(signif(graphData[["meanEAR"]][graphData[["site"]] == "USGS-04024000" &
-                                       graphData[["chnm"]] == "1-Methylnaphthalene"],4),2.279e-06)
+                                       graphData[["chnm"]] == "Naphthalene"],4), 5.729e-05)
   expect_equal(signif(graphData[["meanEAR"]][graphData[["site"]] == "USGS-04024000" &
-                                              graphData[["chnm"]] == "4-Nonylphenol, branched"],4),0.9975)
+                                              graphData[["chnm"]] == "4-Nonylphenol, branched"],4),1.199)
   
   
 })
@@ -186,9 +186,9 @@ test_that("Map stuff functions", {
   expect_type(mapDataList, "list")
   expect_equal(length(mapDataList), 2)
   map_df <- mapDataList[["mapData"]]
-  expect_equal(signif(map_df[["meanMax"]][map_df[["Short Name"]] == "StLouis"],4),1.271)
-  expect_equal(map_df[["count"]][map_df[["Short Name"]] == "StLouis"],26)
-  expect_equal(map_df[["sizes"]][map_df[["Short Name"]] == "StLouis"],6.6)
+  expect_equal(signif(map_df[["meanMax"]][map_df[["Short Name"]] == "StLouis"],4), 1.472)
+  expect_equal(map_df[["count"]][map_df[["Short Name"]] == "StLouis"],31)
+  expect_equal(map_df[["sizes"]][map_df[["Short Name"]] == "StLouis"],7.2)
   
   # Map data:
   map_data <- make_tox_map(chemical_summary, chem_site, "Biological")
@@ -203,14 +203,14 @@ test_that("Table endpoint hits", {
   bt <- endpoint_hits_DT(chemical_summary, category = "Biological")
   expect_type(bt, "list")
   expect_true(all(names(bt$x$data) %in% c("endPoint","Nuclear Receptor","DNA Binding",
-                                  "Phosphatase","Steroid Hormone","Esterase")))
+                                          "Cell Cycle","Steroid Hormone","Esterase")))
   expect_true(all(class(bt) %in% c("datatables","htmlwidget")))
   
   bt_df <- endpoint_hits(chemical_summary, category = "Biological")
   expect_true(all(names(bt_df) %in% c("endPoint","Nuclear Receptor","DNA Binding",     
-                                      "Esterase","Steroid Hormone")))
-  expect_equal(bt_df[["Nuclear Receptor"]][bt_df[["endPoint"]] == "NVS_NR_hPPARg"],11)
-  expect_true(is.na(bt_df[["Esterase"]][bt_df[["endPoint"]] == "NVS_NR_hPPARg"]))
+                                      "Cell Cycle", "Esterase", "Steroid Hormone")))
+  expect_equal(bt_df[["Nuclear Receptor"]][bt_df[["endPoint"]] == "OT_ERa_EREGFP_0120"],10)
+  expect_true(is.na(bt_df[["Esterase"]][bt_df[["endPoint"]] == "OT_ERa_EREGFP_0120"]))
   
   expect_error(endpoint_hits_DT(chemical_summary, category = "Class"))
   
@@ -224,9 +224,9 @@ test_that("Table endpoint hits", {
   cht <- endpoint_hits_DT(chemical_summary, category = "Chemical")
   expect_type(cht, "list")
   
-  expect_true(all(names(cht$x$data) %in% c("endPoint","Bisphenol A","Fluoranthene","Tris(2-chloroethyl) phosphate",
+  expect_true(all(names(cht$x$data) %in% c("endPoint","Bisphenol A","Metolachlor",
                                            "4-Nonylphenol, branched","Triphenyl phosphate",
-                                           "Metolachlor","Atrazine")))
+                                           "Phenanthrene","Atrazine")))
 })
 
 test_that("hits_by_groupings_DT", {
@@ -238,25 +238,25 @@ test_that("hits_by_groupings_DT", {
   expect_true("nSites" %in% names(bt$x$data))
   
   bt_df <- hits_by_groupings(chemical_summary, category = "Chemical Class")
-  expect_true(all(names(bt_df) %in% c("Nuclear Receptor","DNA Binding","Esterase",        
-                                      "Steroid Hormone","Zebrafish")))
+  expect_true(all(names(bt_df) %in% c("Nuclear Receptor","DNA Binding","Cell Cycle", "Esterase",        
+                                      "Steroid Hormone","Zebrafish", "CYP")))
   expect_true(all(c("Detergent Metabolites","Antioxidants","Herbicides") %in% rownames(bt_df)))
-  expect_equal(bt_df[["Nuclear Receptor"]], c(10,11,7,11,rep(0,9)))
+  expect_equal(bt_df[["Nuclear Receptor"]], c(10, 7, 12, rep(0,10)))
   
   expect_error(hits_by_groupings_DT(chemical_summary, category = "Class"))
   
   ct <- hits_by_groupings_DT(chemical_summary, category = "Chemical Class")
   expect_type(ct, "list")
   expect_true(all(class(ct) %in% c("datatables","htmlwidget")))
-  expect_true(all(names(ct$x$data) %in% c(" ","Nuclear Receptor","DNA Binding",
-                                          "Phosphatase","Esterase","Steroid Hormone",
+  expect_true(all(names(ct$x$data) %in% c(" ","Nuclear Receptor","DNA Binding","Cell Cycle",
+                                          "Esterase", "CYP", "Steroid Hormone",
                                           "Zebrafish")))
   
   cht <- hits_by_groupings_DT(chemical_summary, category = "Chemical")
   expect_type(cht, "list")
   
-  expect_true(all(names(cht$x$data) %in% c(" ","Nuclear Receptor","DNA Binding",
-                                           "Phosphatase","Esterase","Steroid Hormone",
+  expect_true(all(names(cht$x$data) %in% c(" ","Nuclear Receptor","DNA Binding", "Cell Cycle",
+                                           "CYP", "Esterase","Steroid Hormone",
                                            "Zebrafish")))
 })
 
@@ -316,6 +316,122 @@ test_that("Calculating completness", {
   graphData2 <- tox_boxplot_data(chemical_summary, "Biological")
   complete_df_cat <- toxEval:::get_complete_set_category(chemical_summary, graphData2, tox_list$chem_site, category = "Biological")
   
-  expect_equal(nrow(complete_df_cat), 855)
+  expect_equal(nrow(complete_df_cat), 1026)
   
-})
\ No newline at end of file
+})
+
+test_that("Calculating concentrations", {
+  testthat::skip_on_cran()
+  
+  summary_conc <- get_concentration_summary(tox_list)
+  
+  expect_equal(nrow(tox_list$chem_data), nrow(summary_conc))
+  expect_equivalent(summary_conc$EAR, chem_data$Value)
+  
+  gd_conc <- graph_chem_data(summary_conc)
+  gd_tox <- graph_chem_data(chemical_summary)
+  
+  combo <- side_by_side_data(gd_conc, gd_tox, 
+                             left_title = "Concentration", 
+                             right_title = "ToxCast")
+  
+  expect_true("guide_side" %in% names(combo))
+  expect_equal(c("Concentration", "ToxCast"), 
+               levels(combo$guide_side) )
+  
+})
+
+test_that("Testing levels", {
+  
+  chem_levels <- levels(chemical_summary$chnm)
+  class_levels <- levels(chemical_summary$Class)
+  
+  gd <- graph_chem_data(chemical_summary)
+  
+  expect_equal(levels(gd$chnm), chem_levels)
+  expect_equal(levels(gd$Class), class_levels)
+  
+  expect_equal(chem_levels, c("Anthraquinone",                         
+                              "Tetrachloroethylene",                    
+                              "Isophorone",                           
+                              "Bromoform",                            
+                              "1,4-Dichlorobenzene",                    
+                              "Methyl salicylate",                      
+                              "Anthracene",                             
+                              "Naphthalene",                            
+                              "Phenanthrene",                           
+                              "Pyrene",                                 
+                              "Fluoranthene",                           
+                              "Benzo(a)pyrene",                         
+                              "Isoquinoline",                           
+                              "6-Acetyl-1,1,2,4,4,7-hexamethyltetralin",
+                              "Indole",                                 
+                              "D-Limonene",                             
+                              "Benzophenone",                           
+                              "Tributyl phosphate",                     
+                              "Tris(2-butoxyethyl) phosphate",          
+                              "Tris(1,3-dichloro-2-propyl) phosphate",
+                              "Cotinine",                              
+                              "dl-Menthol",                             
+                              "Caffeine",                               
+                              "Tris(2-chloroethyl) phosphate",          
+                              "Triphenyl phosphate",                    
+                              "Diethyl phthalate",                      
+                              "p-Cresol",                               
+                              "Triclosan",                              
+                              "DEET",                                   
+                              "Carbazole",                              
+                              "Carbaryl",                               
+                              "Dichlorvos",                             
+                              "5-Methyl-1H-benzotriazole",              
+                              "2-tert-Butyl-4-methoxyphenol",           
+                              "Bisphenol A",                            
+                              "3,4-Dichlorophenyl isocyanate",          
+                              "Prometon",                               
+                              "Bromacil",                               
+                              "Metalaxyl",                              
+                              "Metolachlor",                            
+                              "Atrazine",                               
+                              "Pentachlorophenol",                      
+                              "4-Octylphenol",                          
+                              "4-Cumylphenol",                          
+                              "4-(1,1,3,3-Tetramethylbutyl)phenol",     
+                              "4-Nonylphenol, branched"))
+  expect_equal(class_levels, c("Detergent Metabolites", "Herbicides",                 
+                               "Antioxidants", "Insecticides",               
+                               "Antimicrobial Disinfectants", "Plasticizers",               
+                               "Nonprescription drugs", "Fire Retardants",            
+                               "Flavors and Fragrances", "PAHs",                       
+                               "Miscellaneous", "Solvents",                   
+                               "Dyes/Pigments"))
+  
+  plot_eps <- plot_tox_endpoints(chemical_summary, 
+                                 "Chemical", top_num = 5)
+  
+  expect_equal(tail(levels(plot_eps$data$endPoint),5),
+               c("ATG_TGFb_CIS_up", "ATG_Sox_CIS_up",      
+                 "NVS_NR_hPPARa", "NVS_NR_hER",          
+                 "OT_AR_ARELUC_AG_1440"))
+  
+  plot_stack <- plot_tox_stacks(chemical_summary,category = "Chemical",
+                                chem_site = tox_list$chem_site,
+                                 top_num = 5)
+  
+  expect_equal(levels(plot_stack$data$category),
+               c("4-Nonylphenol, branched", "Bisphenol A",            
+                 "Atrazine", "Metolachlor",            
+                 "Pentachlorophenol", "Others (41)" ))
+  
+  plot_heat <- plot_tox_heatmap(chemical_summary,category = "Chemical",
+                                chem_site = tox_list$chem_site)
+  
+  expect_equal(tail(levels(plot_heat$data$chnm), 5),
+               c("Pentachlorophenol",                 
+                 "4-Octylphenol",                     
+                 "4-Cumylphenol",                     
+                 "4-(1,1,3,3-Tetramethylbutyl)phenol",
+                 "4-Nonylphenol, branched"))
+  
+  
+  
+})
